@@ -45,7 +45,7 @@
 // - first argument === undefined
 //   the "full current-user object" is returned, i.e.:
 //   {
-//       obj: { nick: '...', passhash: '...', salt: '...', etc. },
+//       obj: { nick: '...', eid: '...', etc. },
 //       priv: 'passerby'
 //   }
 //
@@ -70,11 +70,8 @@ define ([
     prototypes
 ) {
 
-    console.log("Entering mfile-www current-user function");
+    console.log("current-user initialization routine");
 
-    // Initialization routine (run only once but the variables are available
-    // to the current-user function and provide storage for the object it
-    // returns)
     var cu = Object.create(prototypes.user),
         ce = cf('currentUser'),
         priv = cf('currentUserPriv'),
@@ -87,11 +84,10 @@ define ([
         $.extend(cu, ce)
     }
 
-    // current-user function
     return function (sw, arg) { 
         var emptyObj = { "nick": null };
         if (sw === 'obj') {
-            // console.log('current-user function called with "obj"');
+            console.log('current-user function called with "obj"', arg);
             if (arg) {
                 console.log('NOTICE: setting current user object to ', arg);
                 cu = arg;
