@@ -67,6 +67,7 @@ define ([
                 // because the reload will make them go away
                 if (cf('testing')) {
                     console.log("Login successful!");
+                    console.log("Login AJAX returned", st);
                     currentUser('obj', st.payload.emp);
                     currentUser('priv', st.payload.priv);
                 } else {
@@ -76,7 +77,9 @@ define ([
             // failure callback
             fc = function (st) {
                 console.log("Login failed", st);
-                $('#result').html('Login failed: code ' + st.payload.code + ' (' + st.payload.message + ')');
+                lib.displayError(
+                    'Login failed: code ' + st.payload.code + ' (' + st.payload.message + ')'
+                );
                 $('input[name="nam"]').focus();
                 $('input[name="pwd"]').val('');
             };
