@@ -61,8 +61,8 @@ define ([
     return function () {
 
         var dummy = Object.create(null),
-            userObject,
-            userPriv;
+            cu,
+            priv;
 
         stack.resetStack();
 
@@ -71,11 +71,15 @@ define ([
         } else {
             $(document.body).html(html.body());
         }
-        userObject = currentUser('obj');
-        userPriv = currentUser('priv');
-        if ( userObject && userPriv ) {
+        cu = currentUser('obj');
+        console.log("root: current user object:", cu);
+        priv = currentUser('priv');
+        console.log("root: current user priv:", priv);
+        if ( cu.eid && priv ) {
+            console.log("Initializing targets");
             targetInit();
         } else {
+            console.log("Initiating login dialog");
             loginDialog();
         }
     
